@@ -1,5 +1,9 @@
 #!/usr/bin/perl
-use strict; use warnings;
+#
+# $Id: getdriverlist.pl 31 2015-02-17 07:04:36Z gomor $
+#
+use strict;
+use warnings;
 
 use Net::Lorcon2 qw(:subs);
 
